summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThierry Volpiatto <thievol@posteo.net>2021-02-04 18:58:44 +0100
committerThierry Volpiatto <thievol@posteo.net>2021-02-04 18:58:44 +0100
commit0c3df6e709128e759895b9925f55aa509ad025e1 (patch)
treeccc5bb60eefb217d77ef63af98bf715904ef3031
parent12c0a295f4181420b9666c0aa81f63bd8b8b087d (diff)
Fix some bug links
-rw-r--r--helm-buffers.el4
-rw-r--r--helm-command.el4
-rw-r--r--helm-eshell.el8
-rw-r--r--helm-files.el46
-rw-r--r--helm-for-files.el2
-rw-r--r--helm-grep.el8
-rw-r--r--helm-imenu.el6
-rw-r--r--helm-info.el4
-rw-r--r--helm-lib.el9
-rw-r--r--helm-misc.el2
-rw-r--r--helm-mode.el48
-rw-r--r--helm-multi-match.el2
-rw-r--r--helm-ring.el4
-rw-r--r--helm-source.el2
-rw-r--r--helm-sys.el4
-rw-r--r--helm-types.el2
-rw-r--r--helm-utils.el2
-rw-r--r--helm.el52
18 files changed, 105 insertions, 104 deletions
diff --git a/helm-buffers.el b/helm-buffers.el
index 313fa87c..87e5dd38 100644
--- a/helm-buffers.el
+++ b/helm-buffers.el
@@ -275,11 +275,11 @@ Note that this variable is buffer-local.")
(defun helm-buffers-list--init ()
(require 'dired)
- ;; Issue #51 Create the list before `helm-buffer' creation.
+ ;; Bug#51 Create the list before `helm-buffer' creation.
;; We were using a global cache in the past and 'candidates was
;; bound to this cache, this was a problem when using more than one
;; source with a different 'buffer-list fn as the same cache was
- ;; reused in each source (issue #1907), now 'candidates attr is set
+ ;; reused in each source (Bug#1907), now 'candidates attr is set
;; directly so that each list of candidates is local to source.
(helm-set-attr 'candidates (funcall (helm-get-attr 'buffer-list)))
(let ((result (cl-loop with allbufs = (memq 'helm-shadow-boring-buffers
diff --git a/helm-command.el b/helm-command.el
index 2858d963..f60ebceb 100644
--- a/helm-command.el
+++ b/helm-command.el
@@ -253,7 +253,7 @@ default to `extended-command-history'."
(format "%d " helm-M-x-prefix-argument)))
"M-x ")))
(setq helm-M-x--timer (run-at-time 1 0.1 'helm-M-x--notify-prefix-arg))
- ;; Fix Issue #2250, add `helm-move-selection-after-hook' which
+ ;; Fix Bug#2250, add `helm-move-selection-after-hook' which
;; reset prefix arg to nil only for this helm session.
(add-hook 'helm-move-selection-after-hook
'helm-M-x--move-selection-after-hook)
@@ -301,7 +301,7 @@ Save COMMAND to `extended-command-history'."
(when command
;; Avoid having `this-command' set to *exit-minibuffer.
(setq this-command command
- ;; Handle C-x z (repeat) Issue #322
+ ;; Handle C-x z (repeat) Bug#322
real-this-command command)
;; If helm-M-x is called with regular emacs completion (kmacro)
;; use the value of arg otherwise use helm-current-prefix-arg.
diff --git a/helm-eshell.el b/helm-eshell.el
index 6eb58cdd..29aa5303 100644
--- a/helm-eshell.el
+++ b/helm-eshell.el
@@ -92,7 +92,7 @@ at point."
(lambda (x)
(cond ((string-match "\\`~/" helm-ec-target)
;; Strip out the first escape char added by
- ;; `comint-quote-filename' before "~" (Issue #1803).
+ ;; `comint-quote-filename' before "~" (Bug#1803).
(substring (comint-quote-filename (abbreviate-file-name x)) 1))
((string-match "\\`/" helm-ec-target)
(comint-quote-filename x))
@@ -154,7 +154,7 @@ at point."
with comps = (all-completions pcomplete-stub table)
unless comps return (prog1 nil
;; Don't add final space when
- ;; there is no completion (issue #1990).
+ ;; there is no completion (Bug#1990).
(setq helm-eshell--quit-flag t)
(message "No completions of %s" pcomplete-stub))
for i in comps
@@ -219,7 +219,7 @@ at point."
(if (and (stringp last)
(not (string= last ""))
(not users-comp)
- ;; Fix completion on "../" see #1832.
+ ;; Fix completion on "../" see bug #1832.
(or (file-exists-p last)
(helm-aand
(file-name-directory last)
@@ -318,7 +318,7 @@ at point."
;; global to pass it to `helm-quit-hook', this
;; space is added when point is just after
;; previous completion and there is no
- ;; more completion, see issue #1832.
+ ;; more completion, see Bug#1832.
(unless (or helm-eshell--quit-flag
(looking-back "/\\'" (1- (point))))
(prog1 t (insert " ")))
diff --git a/helm-files.el b/helm-files.el
index 4aaec1d9..1d517b12 100644
--- a/helm-files.el
+++ b/helm-files.el
@@ -1439,7 +1439,7 @@ this working."
"Command: "
(cl-loop for (a c) in (eshell-read-aliases-list)
;; Positional arguments may be double
- ;; quoted (Issue #1881).
+ ;; quoted (Bug#1881).
when (string-match "[\"]?.*\\(\\$1\\|\\$\\*\\)[\"]?\\s-*&?\\'" c)
collect (propertize a 'help-echo c) into ls
finally return (sort ls 'string<))
@@ -2523,7 +2523,7 @@ Emacs and even the whole system as it eats all memory."
finally return (or result (expand-file-name "/"))))
(defun helm-reduce-file-name-2 (fname level)
- ;; This version comes from issue #2004 (UNC paths) and should fix
+ ;; This version comes from Bug#2004 (UNC paths) and should fix
;; it. It works with local files and remote files as well but not
;; with ftp, see helm-reduce-file-name-1.
(while (> level 0)
@@ -2643,7 +2643,7 @@ hitting C-j on \"..\"."
(helm-aif (and (helm-file-completion-source-p src)
(not (helm-empty-source-p))
;; Prevent dired commands moving to first real
- ;; (Issue #910).
+ ;; (Bug#910).
(or (memq (intern-soft name)
helm-ff-goto-first-real-dired-exceptions)
(not (string-match "\\`[Dd]ired-" name)))
@@ -2704,12 +2704,12 @@ when `helm-pattern' is equal to \"~/\"."
;; but not when renaming, copying etc...,
;; so for this use
;; `helm-ff-move-to-first-real-candidate'
- ;; instead of `helm-next-line' (Issue #910).
+ ;; instead of `helm-next-line' (Bug#910).
(helm-ff-move-to-first-real-candidate))
(helm-get-selection nil nil src))))
(when (and (or (and helm-ff-auto-update-flag
(null helm-ff--deleting-char-backward)
- ;; Issue #295
+ ;; Bug#295
;; File predicates are returning t
;; with paths like //home/foo.
;; So check it is not the case by regexp
@@ -2717,7 +2717,7 @@ when `helm-pattern' is equal to \"~/\"."
;; entering a tramp method e.g /sudo::.
(not (string-match "\\`//" helm-pattern))
(not (eq last-command 'helm-yank-text-at-point)))
- ;; Fix issue #542.
+ ;; Fix Bug#542.
(string= helm-pattern "~/")
;; Only one remaining directory, expand it.
(and (= candnum 1)
@@ -2799,7 +2799,7 @@ avoid errors when called outside helm for debugging purpose."
(if (file-directory-p sub)
sub (replace-regexp-in-string "/\\'" "" sub))))
(t (helm-ff--expand-substitued-pattern pattern)))))
- ;; `file-directory-p' returns t on "/home/me/." (issue #1844).
+ ;; `file-directory-p' returns t on "/home/me/." (Bug#1844).
(if (and (file-directory-p input)
(not (string-match-p "[^.]\\.\\'" input)))
(progn
@@ -2821,7 +2821,7 @@ avoid errors when called outside helm for debugging purpose."
(defun helm-ff--expand-file-name-no-dot (name &optional directory)
"Prevent expanding \"/home/user/.\" to \"/home/user\"."
- ;; Issue #1844 - If user enter "~/." to type an hidden filename
+ ;; Bug#1844 - If user enter "~/." to type an hidden filename
;; don't expand to /home/him e.g.
;; (expand-file-name "~/.") =>"/home/thierry"
;; (helm-ff--expand-substitued-pattern "~/.") =>"/home/thierry/."
@@ -2835,11 +2835,11 @@ avoid errors when called outside helm for debugging purpose."
(getenv "SystemDrive")))
(subst (helm-substitute-in-filename pattern))
;; On Windows use a simple call to `expand-file-name' to
- ;; avoid Issue #2004.
+ ;; avoid Bug#2004.
(expand-fn (if directory
#'expand-file-name
#'helm-ff--expand-file-name-no-dot)))
- ;; Fix issue #2223 with tilde in directory names e.g. "~/tmp/~test/".
+ ;; Fix Bug#2223 with tilde in directory names e.g. "~/tmp/~test/".
(funcall expand-fn (if (string-match-p "\\`~[^/]" subst)
pattern subst)
;; directory is nil on Nix.
@@ -2864,7 +2864,7 @@ and should be used carefully elsewhere, or not at all, using
(insert fname)
(goto-char (point-min))
(when (memq system-type '(windows-nt ms-dos))
- (skip-chars-forward "/")) ;; Avoid infloop in UNC paths Issue #424
+ (skip-chars-forward "/")) ;; Avoid infloop in UNC paths Bug#424
(if (re-search-forward "~.*/?\\|//\\|/[[:alpha:]]:/" nil t)
(let ((match (match-string 0)))
(goto-char (if (or (string= match "//")
@@ -3034,7 +3034,7 @@ debugging purpose."
(when (string-match "\\`/\\(-\\):" pattern)
(setq pattern (replace-match tramp-default-method t t pattern 1)))
;; In some rare cases tramp can return a nil input,
- ;; so be sure pattern is a string for safety (Issue #476).
+ ;; so be sure pattern is a string for safety (Bug#476).
(unless pattern (setq pattern ""))
(cond ((string-match helm-ff-url-regexp pattern) pattern)
((string-match "\\`\\$" pattern)
@@ -3042,7 +3042,7 @@ debugging purpose."
((string= pattern "") "")
((string-match "\\`[.]\\{1,2\\}/\\'" pattern)
(expand-file-name pattern))
- ;; Directories ending by a dot (issue #1940)
+ ;; Directories ending by a dot (Bug#1940)
((string-match "[^/][.]/\\'" pattern)
(expand-file-name pattern))
((string-match ".*\\(~?/?[.]\\{1\\}/\\)\\'" pattern)
@@ -3099,7 +3099,7 @@ debugging purpose."
;; connection and may send a file-error.
(setq helm--ignore-errors (file-remote-p path))
(set-text-properties 0 (length path) nil path)
- ;; Issue #118 allow creation of newdir+newfile.
+ ;; Bug#118 allow creation of newdir+newfile.
(unless (or
;; A tramp file name not completed.
(string= path "@@TRAMP@@")
@@ -3164,7 +3164,7 @@ debugging purpose."
invalid-basedir
(and (not (file-exists-p path)) (string-match "/$" path))
(and helm--url-regexp (string-match helm--url-regexp path)))
- ;; Do NOT filter boring files here (issue #2330).
+ ;; Do NOT filter boring files here (Bug#2330).
(list (helm-ff-filter-candidate-one-by-one path nil t)))
((string= path "") (helm-ff-directory-files "/"))
;; Check here if directory is accessible (not working on Windows).
@@ -3196,7 +3196,7 @@ debugging purpose."
;; disabled, whe don't want PATH to be added on top
;; if it is a directory.
dir-p)
- ;; Do NOT filter boring files here (issue #2330).
+ ;; Do NOT filter boring files here (Bug#2330).
(list (helm-ff-filter-candidate-one-by-one path nil t)))
(helm-ff-directory-files basedir))))))
@@ -3391,14 +3391,14 @@ If PATTERN is a valid directory name, return PATTERN unchanged."
((or (and dir-p tramp-p (string-match ":\\'" pattern))
(string= pattern "")
(and dir-p (<= (length bn) 2))
- ;; Fix Issue #541 when BD have a subdir similar
+ ;; Fix Bug#541 when BD have a subdir similar
;; to BN, don't switch to match plugin
;; which will match both.
(and dir-p (string-match (regexp-quote bn) bd)))
;; Use full PATTERN on e.g "/ssh:host:".
(regexp-quote pattern))
;; Prefixing BN with a space call multi-match completion.
- ;; This allow showing all files/dirs matching BN (Issue #518).
+ ;; This allow showing all files/dirs matching BN (Bug#518).
;; FIXME: some multi-match methods may not work here.
(dir-p (concat (regexp-quote bd) " " (regexp-quote bn)))
((or (not (helm-ff-fuzzy-matching-p))
@@ -3460,7 +3460,7 @@ Note that only existing directories are saved here."
(defun helm-ff-valid-symlink-p (file)
(helm-aif (condition-case-unless-debug nil
;; `file-truename' send error
- ;; on cyclic symlinks (Issue #692).
+ ;; on cyclic symlinks (Bug#692).
(file-truename file)
(error nil))
(file-exists-p it)))
@@ -3721,7 +3721,7 @@ If SKIP-BORING-CHECK is non nil don't filter boring files."
(backup (backup-file-name-p disp)))
;; We want to filter boring files only on the files coming
;; from the output of helm-ff-directory-files not on single
- ;; candidate (issue #2330).
+ ;; candidate (Bug#2330).
(unless (and (not skip-boring-check)
(or (helm-ff-boring-file-p basename)
(helm-ff-git-ignored-p file)))
@@ -4534,7 +4534,7 @@ Use it for non-interactive calls of `helm-find-files'."
;; [FIXME] When `helm-find-files-1' is used directly from lisp
;; and FNAME is an abbreviated path, for some reasons
;; `helm-update' is called many times before resolving
- ;; the abbreviated path (Issue #1939) so be sure to pass a
+ ;; the abbreviated path (Bug#1939) so be sure to pass a
;; full path to helm-find-files-1.
(unless (string-match-p helm-ff-url-regexp fname)
(setq fname (expand-file-name (substitute-in-file-name fname))))
@@ -4644,7 +4644,7 @@ source is `helm-source-find-files'."
(require 'ffap)
;; Avoid "Stack overflow in regexp matcher" error
;; in evil `ffap-guesser' by removing crap `ffap-gopher-at-point'
- ;; (bug fixed in emacs-26 #25391) .
+ ;; (bug fixed in emacs-26 http://debbugs.gnu.org/cgi/bugreport.cgi?bug=25391) .
;; `ffap-machine-at-point' have been removed too as it was anyway
;; disabled with `ffap-machine-p-known' bound to 'reject.
;; `ffap-file-at-point' can be neutralized with
@@ -5661,7 +5661,7 @@ files."
"Allow deleting tramp connection or marked tramp connections at once.
This replace `tramp-cleanup-connection' which is partially broken
-in Emacs < to 25.1.50.1 (See Emacs Bug#24432).
+in Emacs < to 25.1.50.1 (See Emacs bug http://debbugs.gnu.org/cgi/bugreport.cgi?bug=24432).
It allows additionally to delete more than one connection at
once."
diff --git a/helm-for-files.el b/helm-for-files.el
index e442b3e9..eff9152f 100644
--- a/helm-for-files.el
+++ b/helm-for-files.el
@@ -174,7 +174,7 @@ Colorize only symlinks, directories and files."
;; Call file-attributes only if:
;; - file is not remote
;; - helm-for-files--tramp-not-fancy is nil and file is remote AND
- ;; connected. (Issue #1679)
+ ;; connected. (Bug#1679)
for type = (and (or (null isremote)
(and (null helm-for-files-tramp-not-fancy)
(file-remote-p i nil t)))
diff --git a/helm-imenu.el b/helm-imenu.el
index 5a0d9cd0..ad5c454c 100644
--- a/helm-imenu.el
+++ b/helm-imenu.el
@@ -258,7 +258,7 @@ string."
;; If value is an integer, convert it
;; to a marker, otherwise it is a cons cell
;; and it will be converted on next recursions.
- ;; (Issue #1060) [1].
+ ;; (Bug#1060) [1].
(if (integerp v) (copy-marker v) v)))))
((listp (cdr elm))
(and elm (list elm)))
@@ -266,7 +266,7 @@ string."
;; bug in imenu, should not be needed.
(and (cdr elm)
;; Semantic uses overlays whereas imenu uses
- ;; markers (issue #1706).
+ ;; markers (Bug#1706).
(setcdr elm (pcase (cdr elm) ; Same as [1].
((and ov (pred overlayp))
(copy-overlay ov))
@@ -351,7 +351,7 @@ i.e. `derived-mode-p' or it have an association in
:init (lambda ()
;; Use a cache to avoid repeatedly sending
;; progress-reporter message when updating
- ;; (Issue #1704).
+ ;; (Bug#1704).
(setq helm-imenu--in-all-buffers-cache
(helm-imenu-candidates-in-all-buffers)))
:candidates 'helm-imenu--in-all-buffers-cache
diff --git a/helm-lib.el b/helm-lib.el
index 67d71a6f..4a8db3e9 100644
--- a/helm-lib.el
+++ b/helm-lib.el
@@ -406,7 +406,7 @@ Like `this-command' but return the real command, and not
if (and
;; In some case we may have in the way an
;; advice compiled resulting in byte-code,
- ;; ignore it (Issue #691).
+ ;; ignore it (Bug#691).
(symbolp fn)
(commandp fn)
(not (memq fn bl)))
@@ -733,7 +733,7 @@ displayed in BUFNAME."
(not (memq fun helm-help-not-interactive-command)))
;; For movement of cursor in help buffer we need to
;; call interactively commands for impaired people
- ;; using a synthetizer (#1347).
+ ;; using a synthetizer (Bug #1347).
(call-interactively fun)
(funcall fun))))))))
@@ -858,7 +858,7 @@ hashtable itself."
(helm-awhile (helm-basedir (directory-file-name
(expand-file-name directory)))
;; Break at root to avoid infloop, root is / or on Windows
- ;; C:/ i.e. <volume>:/ (issue #2308).
+ ;; C:/ i.e. <volume>:/ (Bug#2308).
(when (string-match-p "\\`[A-Za-z]?:?/\\'" it)
(cl-return nil))
(when (cl-loop for r in black-list
@@ -1274,7 +1274,8 @@ Argument ALIST is an alist of associated major modes."
(defun helm-file-name-sans-extension (filename)
"Same as `file-name-sans-extension' but remove all extensions."
(helm-aif (file-name-sans-extension filename)
- ;; Start searching at index 1 for files beginning with a dot (#1335).
+ ;; Start searching at index 1 for files beginning with a dot
+ ;; (bug#1335).
(if (string-match "\\." (helm-basename it) 1)
(helm-file-name-sans-extension it)
it)))
diff --git a/helm-misc.el b/helm-misc.el
index 6e754620..28557d9d 100644
--- a/helm-misc.el
+++ b/helm-misc.el
@@ -314,7 +314,7 @@ Default action change TZ environment variable locally to emacs."
:multiline t
:keymap helm-minibuffer-history-map
:allow-nest t)))
- ;; Fix issue #1667 with emacs-25+ `query-replace-from-to-separator'.
+ ;; Fix Bug#1667 with emacs-25+ `query-replace-from-to-separator'.
(when (and (boundp 'query-replace-from-to-separator) query-replace-p)
(let ((pos (string-match "\0" elm)))
(and pos
diff --git a/helm-multi-match.el b/helm-multi-match.el
index 5ee35d76..5c09f84c 100644
--- a/helm-multi-match.el
+++ b/helm-multi-match.el
@@ -126,7 +126,7 @@ If GREP-SPACE is used translate escaped space to \"\\s\" instead of \"\\s-\"."
(defun helm-mm-prefix-match (candidate &optional pattern)
;; In filename completion basename and basedir may be
- ;; quoted, unquote them for string comparison (Issue #1283).
+ ;; quoted, unquote them for string comparison (Bug#1283).
(setq pattern (replace-regexp-in-string
"\\\\" "" (or pattern helm-pattern)))
(let ((len (length pattern)))
diff --git a/helm-source.el b/helm-source.el
index 795e8be5..0ba7d4db 100644
--- a/helm-source.el
+++ b/helm-source.el
@@ -1028,7 +1028,7 @@ an eieio class."
(if (stringp (car action))
(car action)
;; It comes from :persistent-action
- ;; (function . 'nosplit) Fix Issue #788.
+ ;; (function . 'nosplit) Fix Bug#788.
(if (or (symbolp action)
(functionp action))
(helm-symbol-name action)))))
diff --git a/helm-sys.el b/helm-sys.el
index 250ef97b..6174ab2d 100644
--- a/helm-sys.el
+++ b/helm-sys.el
@@ -119,7 +119,7 @@ This affects also sorting functions in the same way."
(when (and (helm--alive-p) (null no-update))
;; Fix quitting while process is running
;; by binding `with-local-quit' in init function
- ;; Issue #1521.
+ ;; Bug#1521.
(helm-force-update
(cl-ecase helm-top-poll-preselection
(candidate (replace-regexp-in-string
@@ -340,7 +340,7 @@ Show actions only on line starting by a PID."
(interactive)
(helm-top-set-mode-line "CPU")
;; Force sorting by CPU even if some versions of top are using by
- ;; default CPU sorting (Issue #1908).
+ ;; default CPU sorting (Bug#1908).
(setq helm-top-sort-fn 'helm-top-sort-by-cpu)
(helm-update (helm-top--preselect-fn)))
diff --git a/helm-types.el b/helm-types.el
index cef1c64c..3e78ded0 100644
--- a/helm-types.el
+++ b/helm-types.el
@@ -211,7 +211,7 @@
(setf (slot-value source 'mode-line)
;; Use default-value of `helm-mode-line-string' in case user
;; starts with a helm buffer as current-buffer otherwise the
- ;; local value of this helm buffer is used (issues #1517,#2377).
+ ;; local value of this helm buffer is used (bug#1517, bug#2377).
(list "Buffer(s)" (default-value 'helm-mode-line-string)))
(setf (slot-value source 'filtered-candidate-transformer)
'(helm-skip-boring-buffers
diff --git a/helm-utils.el b/helm-utils.el
index fd6d7ff5..5a41b098 100644
--- a/helm-utils.el
+++ b/helm-utils.el
@@ -491,7 +491,7 @@ Default is `helm-current-buffer'."
#'markdown-show-entry)))
(hs-show-hook (list (lambda () (goto-char loc)))))
;; outline may fail in some conditions e.g. with markdown enabled
- ;; (issue #1919).
+ ;; (Bug#1919).
(condition-case-unless-debug nil
(and fn (funcall fn))
(error nil))))
diff --git a/helm-grep.el b/helm-grep.el
index 4f9ab18c..440097b6 100644
--- a/helm-grep.el
+++ b/helm-grep.el
@@ -434,7 +434,7 @@ It is intended to use as a let-bound variable, DON'T set this globaly.")
;; When user mark files and use recursion with grep
;; backend enabled, the loop collect on each marked
;; candidate its `file-name-directory' and we endup with
;; duplicates (Issue #1714). FIXME: For now as a quick fix
;; I just remove dups here but I should handle this inside
;; the cond above.
(setq files (helm-fast-remove-dups files :test 'equal))
@@ -954,7 +954,7 @@ Special commands:
"Return a list of known ack-grep types."
(with-temp-buffer
;; "--help-types" works with both 1.96 and 2.1+, while
;; "--help types" works only with 1.96 Issue #422.
;; `helm-grep-command' should return the ack executable
;; when this function is used in the right context
;; i.e After checking is we are using ack-grep with
@@ -1220,7 +1220,7 @@ matching `helm-zgrep-file-extension-regexp' only."
;; Filename should always be provided as a local
;; path, if the root directory is remote, the
;; tramp prefix will be added before executing
;; action, see `helm-grep-action' and issue #2032.
(expand-file-name (car split)
(or (file-remote-p root 'localname)
root))
@@ -1274,7 +1274,7 @@ matching `helm-zgrep-file-extension-regexp' only."
(let (beg end)
(condition-case-unless-debug nil
(with-temp-buffer
- (insert (propertize str 'read-only nil)) ; Fix (#1176)
+ (insert (propertize str 'read-only nil)) ; Fix bug#1176
(goto-char (point-min))
(cl-loop for reg in
(cl-loop for r in (helm-mm-split-pattern
@@ -434,7 +434,7 @@ It is intended to use as a let-bound variable, DON'T set this globaly.")
;; backend enabled, the loop collect on each marked
;; candidate its `file-name-directory' and we endup with
- ;; duplicates (Issue #1714). FIXME: For now as a quick fix
+ ;; duplicates (Bug#1714). FIXME: For now as a quick fix
;; I just remove dups here but I should handle this inside
;; the cond above.
@@ -954,7 +954,7 @@ Special commands:
(with-temp-buffer
;; "--help-types" works with both 1.96 and 2.1+, while
- ;; "--help types" works only with 1.96 Issue #422.
+ ;; "--help types" works only with 1.96 Bug#422.
;; `helm-grep-command' should return the ack executable
;; when this function is used in the right context
@@ -1220,7 +1220,7 @@ matching `helm-zgrep-file-extension-regexp' only."
;; path, if the root directory is remote, the
;; tramp prefix will be added before executing
- ;; action, see `helm-grep-action' and issue #2032.
+ ;; action, see `helm-grep-action' and Bug#2032.
(expand-file-name (car split)
(or (file-remote-p root 'localname)
diff --git a/helm-info.el b/helm-info.el
index 5b343ad7..0311ea9e 100644
--- a/helm-info.el
+++ b/helm-info.el
@@ -67,7 +67,7 @@ files with `helm-info-at-point'."
(while (search-forward "\n* " nil t)
(unless (search-forward "Menu:\n" (1+ (point-at-eol)) t)
(setq start (point-at-bol)
;; Fix issue #1503 by getting the invisible
;; info displayed on next line in long strings.
;; e.g "* Foo.\n (line 12)" instead of
;; "* Foo.(line 12)"
@@ -154,7 +154,7 @@ Elements of the list are strings of Info file names without
extensions (e.g., \"emacs\" for file \"emacs.info.gz\"). Info
files are found by searching directories in
`Info-directory-list'."
- (info-initialize) ; Build Info-directory-list from INFOPATH (Issue #2118)
+ (info-initialize) ; Build Info-directory-list from INFOPATH (Bug#2118)
(let ((files (cl-loop for d in (or Info-directory-list
Info-default-directory-list)
when (file-directory-p d)
@@ -67,7 +67,7 @@ files with `helm-info-at-point'."
(unless (search-forward "Menu:\n" (1+ (point-at-eol)) t)
(setq start (point-at-bol)
- ;; Fix issue #1503 by getting the invisible
+ ;; Fix Bug#1503 by getting the invisible
;; info displayed on next line in long strings.
;; e.g "* Foo.\n (line 12)" instead of
diff --git a/helm-mode.el b/helm-mode.el
index 0431f707..d76a0e97 100644
--- a/helm-mode.el
+++ b/helm-mode.el
@@ -394,13 +394,13 @@ data would not be fully collected at init time.
If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
;; Ensure COLLECTION is computed from `helm-current-buffer'
;; because some functions used as COLLECTION work
;; only in the context of current-buffer (Issue #1030) .
(with-helm-current-buffer
(let ((cands
(cond ((vectorp collection)
(all-completions input collection test))
((and (symbolp collection) (boundp collection)
;; Issue #324 history is let-bounded and given
;; quoted as hist argument of completing-read.
;; See example in `rcirc-browse-url'.
(symbolp (symbol-value collection)))
@@ -446,7 +446,7 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
(funcall collection input test t))
((and alistp (null test)) collection)
;; Next test ensure circular objects are removed
- ;; with `all-completions' (Issue #1530).
+ ;; with `all-completions' (Bug#1530).
(t (all-completions input collection test)))))
(if sort-fn (sort cands sort-fn) cands))))
@@ -468,7 +468,7 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
(setq candidates (append (list
;; Unquote helm-pattern
;; when it is added
- ;; as candidate: Why? #2015
+ ;; as candidate: Why? (bug #2015)
;; (replace-regexp-in-string
;; "\\s\\" "" helm-pattern)
helm-pattern)
@@ -498,7 +498,7 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
(defun helm-comp-read--move-to-first-real-candidate ()
(helm-aif (helm-get-selection nil 'withprop)
;; Avoid error with candidates with an image as display (#2296).
(when (equal (get-text-property 0 'display it) "[?]")
(helm-next-line))))
@@ -687,7 +687,7 @@ that use `helm-comp-read'. See `helm-M-x' for example."
;; and :alistp is nil INPUT is passed to
;; `all-completions' which defeat helm
;; matching functions (multi match, fuzzy
- ;; etc...) issue #2134.
+ ;; etc...) Bug#2134.
collection test sort alistp
(if (and match-dynamic (null candidates-in-buffer))
helm-pattern ""))))
@@ -709,7 +709,7 @@ that use `helm-comp-read'. See `helm-M-x' for example."
;; Input is added to history in completing-read's
;; and may be regexp-quoted, so unquote it
;; but check if cand is a string (it may be at this stage
- ;; a symbol or nil) Issue #1553.
+ ;; a symbol or nil) Bug#1553.
when (stringp i)
collect (replace-regexp-in-string "\\s\\" "" i))))
(and hist-fc-transformer (helm-mklist hist-fc-transformer)))
@@ -793,7 +793,7 @@ that use `helm-comp-read'. See `helm-M-x' for example."
;; Avoid adding an incomplete input to history.
(when (and result history del-input)
(cond ((and (symbolp history) ; History is a symbol.
- (not (symbolp (symbol-value history)))) ; Fix Issue #324.
+ (not (symbolp (symbol-value history)))) ; Fix Bug#324.
;; Be sure history is not a symbol with a nil value.
(helm-aif (symbol-value history) (setcar it result)))
((consp history) ; A list with a non--nil value.
@@ -1100,13 +1100,13 @@ See documentation of `completing-read' and `all-completions' for details."
;; Note: `minibuffer-with-setup-hook' may setup a lambda
;; calling `minibuffer-completion-help' or other minibuffer
;; functions we DONT WANT here, in these cases removing the hook
;; (a symbol) have no effect. Issue #448.
;; Because `minibuffer-completion-table' and
;; `minibuffer-completion-predicate' are not bound
;; anymore here, these functions should have no effect now,
;; except in some rare cases like in `woman-file-name',
;; so remove all incompatible functions
- ;; from `minibuffer-setup-hook' (Issue #1205, #1240).
+ ;; from `minibuffer-setup-hook' (Bug#1205, Bug#1240).
;; otherwise helm have not the time to close its initial session.
(minibuffer-setup-hook
(cl-loop for h in minibuffer-setup-hook
@@ -1489,7 +1489,7 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
(file-name-as-directory fname)
fname)))
;; Read file name handler with history (issue #1652)
(defun helm-read-file-name-handler-1 (prompt dir default-filename
mustmatch initial predicate
name buffer)
@@ -1622,11 +1622,11 @@ Actually does nothing."
(all-completions "" (or all collection)
(lambda (x &optional _y)
;; Second arg _y is needed when
- ;; COLLECTION is a hash-table issue
- ;; #2231 (C-x 8 RET).
+ ;; COLLECTION is a hash-table (Bug#2231)
+ ;; (C-x 8 RET).
;; Elements of COLLECTION may be
;; lists or alists, in this case consider the
;; car of element (issue #2219 org-refile).
(let ((elm (if (listp x) (car x) x)))
;; PREDICATE have been already called in
;; initial all-completions, no need to call
@@ -1760,7 +1760,7 @@ Can be used for `completion-in-region-function' by advicing it with an
(if (cdr-safe it) (car it) it)))
;; This hook force usage of the display part of candidate with
;; its properties, this is needed for lsp-mode in its
- ;; :exit-function see issue #2265.
+ ;; :exit-function see Bug#2265.
(add-hook 'helm-before-action-hook 'helm-completion-in-region--selection)
(unwind-protect
(let* ((enable-recursive-minibuffers t)
@@ -1794,7 +1794,7 @@ Can be used for `completion-in-region-function' by advicing it with an
;; `afun' is a closure to call against each string in `data'.
;; it provide the annotation info for each string.
;; e.g "foo" => "foo <f>" where foo is a function.
- ;; See Issue #407.
+ ;; See Bug#407.
(afun (or (plist-get completion-extra-properties :annotation-function)
(completion-metadata-get metadata 'annotation-function)))
(init-space-suffix (unless (or (memq helm-completion-style '(helm-fuzzy emacs))
@@ -1912,11 +1912,11 @@ Can be used for `completion-in-region-function' by advicing it with an
(setq string (copy-sequence result))
(helm-completion-in-region--insert-result
result start point end base-size))
;; Allow running extra property `:exit-function' (Issues #2265,
;; #2356). Function is called with 'exact if for a unique
;; match which is exact, the return value of `try-completion'
;; is t or a string ending with "/" i.e. possibly a directory
- ;; (issue #2274),
+ ;; (Bug#2274),
;; otherwise it is called with 'finished.
(when (and (stringp string) exit-fun)
(let ((tcomp (try-completion initial-input collection)))
@@ -1946,7 +1946,7 @@ Be sure to know what you are doing when modifying this.")
;; When RESULT have annotation, annotation is displayed
;; in it with a display property attached to a space
;; added at end of string, take care of removing this
;; space (issue #2360). However keep RESULT intact to
;; pass it to `:exit-function' i.e. Don't store the
;; modified string in STRING.
(choose-completion-string
@@ -1965,7 +1965,7 @@ Be sure to know what you are doing when modifying this.")
(let ((beg (+ start base-size))
(sep (or (and
;; If `crm-separator' is a string of length 1
;; assume it can be used as separator (#2298),
;; otherwise it is a regexp and use the value
;; it matches or default to "," if no match.
(eq (length crm-separator) 1)
@@ -1975,7 +1975,7 @@ Be sure to know what you are doing when modifying this.")
;; regexp use the string the regexp is matching.
;; If SEP is not a string, it have been probably bound to a
;; symbol or nil through `helm-crm-default-separator' that serve
;; as a flag to say "Please no separator" (Issue #2353 with
;; `magit-completing-read-multiple').
(if (stringp sep)
(save-excursion
@@ -2045,11 +2045,11 @@ Note: This mode is incompatible with Emacs23."
#'helm--completion-in-region))
;; If user have enabled ido-everywhere BEFORE enabling
;; helm-mode disable it and warn user about its
- ;; incompatibility with helm-mode (issue #2085).
+ ;; incompatibility with helm-mode (Bug#2085).
(helm-mode--disable-ido-maybe)
;; If ido-everywhere is not enabled yet anticipate and
;; disable it if user attempt to enable it while helm-mode
- ;; is running (issue #2085).
+ ;; is running (Bug#2085).
(add-hook 'ido-everywhere-hook #'helm-mode--ido-everywhere-hook)
(when (fboundp 'ffap-read-file-or-url-internal)
;; `ffap-read-file-or-url-internal' have been removed in
@@ -394,13 +394,13 @@ data would not be fully collected at init time.
;; Ensure COLLECTION is computed from `helm-current-buffer'
;; because some functions used as COLLECTION work
- ;; only in the context of current-buffer (Issue #1030) .
+ ;; only in the context of current-buffer (Bug#1030) .
(with-helm-current-buffer
(let ((cands
@@ -394,13 +394,13 @@ data would not be fully collected at init time.
(all-completions input collection test))
((and (symbolp collection) (boundp collection)
- ;; Issue #324 history is let-bounded and given
+ ;; Bug#324 history is let-bounded and given
;; quoted as hist argument of completing-read.
;; See example in `rcirc-browse-url'.
@@ -498,7 +498,7 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
(defun helm-comp-read--move-to-first-real-candidate ()
(helm-aif (helm-get-selection nil 'withprop)
- ;; Avoid error with candidates with an image as display (#2296).
+ ;; Avoid error with candidates with an image as display (bug #2296).
(when (equal (get-text-property 0 'display it) "[?]")
(helm-next-line))))
@@ -1100,13 +1100,13 @@ See documentation of `completing-read' and `all-completions' for details."
;; calling `minibuffer-completion-help' or other minibuffer
;; functions we DONT WANT here, in these cases removing the hook
- ;; (a symbol) have no effect. Issue #448.
+ ;; (a symbol) have no effect. Bug#448.
;; Because `minibuffer-completion-table' and
;; `minibuffer-completion-predicate' are not bound
@@ -1489,7 +1489,7 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
(file-name-as-directory fname)
fname)))
-;; Read file name handler with history (issue #1652)
+;; Read file name handler with history (Bug#1652)
(defun helm-read-file-name-handler-1 (prompt dir default-filename
mustmatch initial predicate
@@ -1622,11 +1622,11 @@ Actually does nothing."
;; Elements of COLLECTION may be
;; lists or alists, in this case consider the
- ;; car of element (issue #2219 org-refile).
+ ;; car of element (Bug#2219 org-refile).
(let ((elm (if (listp x) (car x) x)))
;; PREDICATE have been already called in
@@ -1912,11 +1912,11 @@ Can be used for `completion-in-region-function' by advicing it with an
(helm-completion-in-region--insert-result
result start point end base-size))
- ;; Allow running extra property `:exit-function' (Issues #2265,
- ;; #2356). Function is called with 'exact if for a unique
+ ;; Allow running extra property `:exit-function' (Bug#2265,
+ ;; Bug#2356). Function is called with 'exact if for a unique
;; match which is exact, the return value of `try-completion'
;; is t or a string ending with "/" i.e. possibly a directory
@@ -1946,7 +1946,7 @@ Be sure to know what you are doing when modifying this.")
;; in it with a display property attached to a space
;; added at end of string, take care of removing this
- ;; space (issue #2360). However keep RESULT intact to
+ ;; space (Bug#2360). However keep RESULT intact to
;; pass it to `:exit-function' i.e. Don't store the
;; modified string in STRING.
@@ -1965,7 +1965,7 @@ Be sure to know what you are doing when modifying this.")
(sep (or (and
;; If `crm-separator' is a string of length 1
- ;; assume it can be used as separator (#2298),
+ ;; assume it can be used as separator (bug #2298),
;; otherwise it is a regexp and use the value
;; it matches or default to "," if no match.
@@ -1975,7 +1975,7 @@ Be sure to know what you are doing when modifying this.")
;; If SEP is not a string, it have been probably bound to a
;; symbol or nil through `helm-crm-default-separator' that serve
- ;; as a flag to say "Please no separator" (Issue #2353 with
+ ;; as a flag to say "Please no separator" (Bug#2353 with
;; `magit-completing-read-multiple').
(if (stringp sep)
diff --git a/helm-ring.el b/helm-ring.el
index fbe2fef0..66f8ebbf 100644
--- a/helm-ring.el
+++ b/helm-ring.el
@@ -191,7 +191,7 @@ yanked string."
;; Adding a `delete-selection' property
;; to `helm-kill-ring-action' is not working
;; because `this-command' will be `helm-maybe-exit-minibuffer',
;; so use this workaround (Issue #1520).
(when (and (region-active-p) delete-selection-mode)
(delete-region (region-beginning) (region-end)))
(if (not (eq (helm-get-attr 'last-command helm-source-kill-ring) 'yank))
@@ -438,7 +438,7 @@ This is a command for `helm-kill-ring-map'."
'kill-new
'append-to-register
'prepend-to-register)))
- unless (null string-actions) ; Fix Issue #1107.
+ unless (null string-actions) ; Fix Bug#1107.
collect (cons (format "Register %3s:\n %s" key (car string-actions))
(cons char (cdr string-actions)))))
@@ -191,7 +191,7 @@ yanked string."
;; to `helm-kill-ring-action' is not working
;; because `this-command' will be `helm-maybe-exit-minibuffer',
- ;; so use this workaround (Issue #1520).
+ ;; so use this workaround (Bug#1520).
(when (and (region-active-p) delete-selection-mode)
(delete-region (region-beginning) (region-end)))
diff --git a/helm.el b/helm.el
index eb3c0a44..3c946826 100644
--- a/helm.el
+++ b/helm.el
@@ -2585,7 +2585,7 @@ of current source only."
while (not (if in-current-source
(or (helm-pos-header-line-p) (eobp))
(eobp)))
;; Don't count empty lines maybe added by popup (#1370).
unless (or (eq (point-at-bol) (point-at-eol))
(helm-pos-header-line-p))
do (cl-incf ln)
@@ -2828,7 +2828,7 @@ HISTORY args see `helm'."
(advice-add 'epa-passphrase-callback-function
:around #'helm--suspend-read-passwd)
;; Ensure linum-mode is disabled in Helm buffers to preserve
- ;; performances (Issue #1894).
+ ;; performances (Bug#1894).
(advice-add 'linum-on :override #'helm--advice-linum-on '((depth . 100))))
(helm-log (concat "[Start session] " (make-string 41 ?+)))
(helm-log "prompt = %S" prompt)
@@ -2840,7 +2840,7 @@ HISTORY args see `helm'."
(setq helm--prompt (or prompt "pattern: "))
(let ((non-essential t)
;; Prevent mouse jumping to the upper-right
;; hand corner of the frame (#1538).
mouse-autoselect-window
focus-follows-mouse
mode-line-in-non-selected-windows
@@ -2876,7 +2876,7 @@ HISTORY args see `helm'."
(helm--remap-mouse-mode 1)) ; Disable mouse bindings.
(add-hook 'post-command-hook 'helm--maybe-update-keymap)
;; Add also to update hook otherwise keymap is not updated
;; until a key is hitted (Issue #1670).
(add-hook 'helm-after-update-hook 'helm--maybe-update-keymap)
(add-hook 'post-command-hook 'helm--update-header-line)
(helm-log "show prompt")
@@ -3186,7 +3186,7 @@ frame configuration as per `helm-save-configuration-functions'."
;;
;; Since they don't know about the new timestamp,
;; their keyboard handling can break after a helm
;; user quits emacs, as reported in #1641.
;;
;; Fortunately for us, we really don't need this
;; XSetInputFocus call, since we already have focus
@@ -3618,7 +3618,7 @@ Helm was started, use `helm-current-buffer' instead."
;; as `helm-current-buffer', this allow to use helm
;; from an already active minibuffer (M-: etc...)
(window-buffer (active-minibuffer-window))
- ;; Fix Issue #456
+ ;; Fix Bug#456
;; Use this instead of `current-buffer' to ensure
;; helm session started in helm-mode from a completing-read
;; Use really the buffer where we started and not the one
@@ -3867,7 +3867,7 @@ map)."
;; e.g C-x C-f M-y C-g
;; => *find-files have now the bindings of *kill-ring.
;; It is no more true now we are using `minor-mode-overriding-map-alist'
;; and `helm--minor-mode' thus it fix issue #1076 for emacs-24.3
;; where concurrent timers are not supported.
;; i.e update keymap+check input.
(with-current-buffer (window-buffer (minibuffer-window))
@@ -3906,7 +3906,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
(let ((frame (selected-frame)))
(setq cursor-type t)
;; Ensure restoring default-value of mode-line to allow user
;; using the mouse when helm is inactive (issues #1517,#2377).
(setq mode-line-format (default-value 'mode-line-format))
(remove-hook 'post-command-hook 'helm--maybe-update-keymap)
(remove-hook 'post-command-hook 'helm--update-header-line)
@@ -3996,7 +3996,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
"Retrieve and return the list of candidates from SOURCE."
(let* ((candidate-fn (assoc-default 'candidates source))
(candidate-proc (assoc-default 'candidates-process source))
;; See comment in helm-get-cached-candidates (Issue #2113).
(inhibit-quit candidate-proc)
cfn-error
(notify-error
@@ -4033,7 +4033,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
;; Can happen when the output of a process
;; is empty, and the candidates function call
;; something like (split-string (buffer-string) "\n")
;; which result in a list of one empty string (Issue #938).
;; e.g (completing-read "test: " '(""))
(equal candidates '("")))
nil)
@@ -4061,7 +4061,7 @@ Cache the candidates if there is no cached value yet."
(candidate-cache (gethash name helm-candidate-cache))
;; Bind inhibit-quit to ensure function terminate in case of
;; quit from helm-while-no-input and processes are added to
;; helm-async-processes for further deletion (Issue #2113).
(inhibit-quit (assoc-default 'candidates-process source)))
(helm-aif candidate-cache
(prog1 it (helm-log "Use cached candidates"))
@@ -4170,7 +4170,7 @@ If \(candidate-number-limit\) is in SOURCE, show all candidates in SOURCE.
If \(candidate-number-limit . 123\) is in SOURCE limit candidate to 123."
(helm-aif (assq 'candidate-number-limit source)
;; When assoc value is nil use by default 99999999 otherwise use
;; the assoc value, when it is a symbol interpret its value (#1831).
(or (helm-aand (cdr it) (helm-interpret-value it)) 99999999)
(or helm-candidate-number-limit 99999999)))
@@ -4403,7 +4403,7 @@ to the matching method in use."
(with-temp-buffer
;; Insert the whole display part and remove non--match-part
;; to keep their original face properties.
- (insert (propertize (or mp display) 'read-only nil)) ; Fix (#1176)
+ (insert (propertize (or mp display) 'read-only nil)) ; Fix (bug#1176)
(goto-char (point-min))
(condition-case nil
(progn
@@ -4733,7 +4733,7 @@ without recomputing them, it should be a list of lists."
for mtc in matches
do (helm-render-source src mtc))
;; Move to first line only when there is matches
;; to avoid cursor moving upside down (issue #1703).
(helm--update-move-first-line)))
;; When there is only one async source, update mode-line and run
;; `helm-after-update-hook' in `helm-output-filter--post-process',
@@ -4767,7 +4767,7 @@ without recomputing them, it should be a list of lists."
(helm-aif (assq 'requires-pattern source) (or (cdr it) 1) 0))
;; Entering repeatedly these strings (*, ?) takes 100% CPU
;; and hang emacs on MacOs preventing deleting backward those
- ;; characters (issue #1802).
+ ;; characters (Bug#1802).
(not (string-match-p "\\`[*]+\\'" helm-pattern))
;; These incomplete regexps hang helm forever
;; so defer update. Maybe replace spaces quoted when using
@@ -5116,7 +5116,7 @@ This will work only in Emacs-26+, i.e. Emacs versions that have
;; incomplete-line-info assumed output was truncated in
;; only two chunks. But output could be large and
;; truncated in more than two chunks. Therefore store
;; 'newline' to contain the previous chunks (Issue #1187).
finally do (setcdr incomplete-line-info newline))))
(defun helm-output-filter--post-process ()
@@ -5259,7 +5259,7 @@ If action buffer is selected, back to the Helm buffer."
(helm-subr-native-elisp-p actions))
"Anonymous" actions))
(helm-show-action-buffer actions)
;; Be sure the minibuffer is entirely deleted (#907).
(helm--delete-minibuffer-contents-from "")
(helm--set-action-prompt)
(helm-check-minibuffer-input))))
@@ -5453,7 +5453,7 @@ mode and header lines."
(with-selected-window (minibuffer-window)
(when helm-display-header-line
;; Prevent cursor movement over the overlay displaying
- ;; persistent-help in minibuffer (issue #2108).
+ ;; persistent-help in minibuffer (Bug#2108).
(setq-local disable-point-adjustment t))
(let* ((beg (save-excursion (vertical-motion 0 (helm-window)) (point)))
(end (save-excursion (end-of-visual-line) (point)))
@@ -5469,11 +5469,11 @@ mode and header lines."
"->"
'face 'helm-header-line-left-margin))))
(pos (- (point) beg)))
;; Increment pos each time we find a "%" up to current-pos (#1648).
(cl-loop for c across (buffer-substring-no-properties beg (point))
when (eql c ?%) do (cl-incf pos))
;; Increment pos when cursor is on a "%" to make it visible in header-line
- ;; i.e "%%|" and not "%|%" (#1649).
+ ;; i.e "%%|" and not "%|%" (bug#1649).
(when (eql (char-after) ?%) (setq pos (1+ pos)))
(setq cont (replace-regexp-in-string "%" "%%" cont))
(with-helm-buffer
@@ -5694,7 +5694,7 @@ Key arg DIRECTION can be one of:
(forward-line 1) (eobp)))
;; Empty source at eob are just
;; not displayed unless they are dummy.
- ;; Issue #1117.
+ ;; Bug#1117.
(helm-get-next-header-pos))
(point-min))))
@@ -6095,7 +6095,7 @@ Optional argument SOURCE is a Helm source object."
(re-search-forward (cdr candidate-or-regexp) nil t))
(re-search-forward candidate-or-regexp nil t))
;; If search fall on an header line continue loop
;; until it match or fail (Issue #1509).
(unless (helm-pos-header-line-p) (cl-return (setq mp it))))
(goto-char (or mp start)))))
(forward-line 0) ; Avoid scrolling right on long lines.
@@ -6499,7 +6499,7 @@ before running again the init function."
(global global-bname)
(local local-bname)))
;; We need a buffer not read-only to perhaps insert later
;; text coming from read-only buffers (issue #1176).
(set (make-local-variable 'buffer-read-only) nil)
;; Undo is automatically disabled in buffer names starting
;; with a space, so no need to disable it.
@@ -6839,7 +6839,7 @@ unsuitable window to display persistent action buffer."
((and helm--buffer-in-new-frame-p helm-initial-frame)
(with-selected-frame helm-initial-frame (selected-window)))
((and split (not (eq split 'never))) (split-window))
;; Fix Issue #2050 with dedicated window.
((and (window-dedicated-p
(setq prev-win (previous-window (selected-window) 1)))
(not (eq split 'never)))
@@ -7064,7 +7064,7 @@ starting it is not needed."
;; Non existing files in HFF and
;; RFN. Display may be an image. See
;; https://github.com/yyoncho/helm-treemacs-icons/issues/5
- ;; and also issue #2296.
+ ;; and also Bug#2296.
(equal prefix "[?]")
(and filecomp-p
(or
@@ -7196,7 +7196,7 @@ sources."
;; than the one stored in overlay.
;; This is needed when some cands have same display names.
;; Using equal allow testing any type of value for real cand.
- ;; Issue (#706).
+ ;; bug#706.
(and (equal (overlay-get o 'real) real)
(move-overlay o beg end))
(and (equal o-str (buffer-substring beg end))
@@ -2585,7 +2585,7 @@ of current source only."
(or (helm-pos-header-line-p) (eobp))
(eobp)))
- ;; Don't count empty lines maybe added by popup (#1370).
+ ;; Don't count empty lines maybe added by popup (bug#1370).
unless (or (eq (point-at-bol) (point-at-eol))
(helm-pos-header-line-p))
@@ -2840,7 +2840,7 @@ HISTORY args see `helm'."
(let ((non-essential t)
;; Prevent mouse jumping to the upper-right
- ;; hand corner of the frame (#1538).
+ ;; hand corner of the frame (bug#1538).
mouse-autoselect-window
focus-follows-mouse
@@ -2876,7 +2876,7 @@ HISTORY args see `helm'."
(add-hook 'post-command-hook 'helm--maybe-update-keymap)
;; Add also to update hook otherwise keymap is not updated
- ;; until a key is hitted (Issue #1670).
+ ;; until a key is hitted (Bug#1670).
(add-hook 'helm-after-update-hook 'helm--maybe-update-keymap)
(add-hook 'post-command-hook 'helm--update-header-line)
@@ -3186,7 +3186,7 @@ frame configuration as per `helm-save-configuration-functions'."
;; Since they don't know about the new timestamp,
;; their keyboard handling can break after a helm
- ;; user quits emacs, as reported in #1641.
+ ;; user quits emacs, as reported in bug#1641.
;;
;; Fortunately for us, we really don't need this
@@ -3867,7 +3867,7 @@ map)."
;; => *find-files have now the bindings of *kill-ring.
;; It is no more true now we are using `minor-mode-overriding-map-alist'
- ;; and `helm--minor-mode' thus it fix issue #1076 for emacs-24.3
+ ;; and `helm--minor-mode' thus it fix Bug#1076 for emacs-24.3
;; where concurrent timers are not supported.
;; i.e update keymap+check input.
@@ -3906,7 +3906,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
(setq cursor-type t)
;; Ensure restoring default-value of mode-line to allow user
- ;; using the mouse when helm is inactive (issues #1517,#2377).
+ ;; using the mouse when helm is inactive (Bug#1517,Bug#2377).
(setq mode-line-format (default-value 'mode-line-format))
(remove-hook 'post-command-hook 'helm--maybe-update-keymap)
@@ -3996,7 +3996,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
(let* ((candidate-fn (assoc-default 'candidates source))
(candidate-proc (assoc-default 'candidates-process source))
- ;; See comment in helm-get-cached-candidates (Issue #2113).
+ ;; See comment in helm-get-cached-candidates (Bug#2113).
(inhibit-quit candidate-proc)
cfn-error
@@ -4033,7 +4033,7 @@ WARNING: Do not use this mode yourself, it is internal to Helm."
;; is empty, and the candidates function call
;; something like (split-string (buffer-string) "\n")
- ;; which result in a list of one empty string (Issue #938).
+ ;; which result in a list of one empty string (Bug#938).
;; e.g (completing-read "test: " '(""))
(equal candidates '("")))
@@ -4061,7 +4061,7 @@ Cache the candidates if there is no cached value yet."
;; Bind inhibit-quit to ensure function terminate in case of
;; quit from helm-while-no-input and processes are added to
- ;; helm-async-processes for further deletion (Issue #2113).
+ ;; helm-async-processes for further deletion (Bug#2113).
(inhibit-quit (assoc-default 'candidates-process source)))
(helm-aif candidate-cache
@@ -4170,7 +4170,7 @@ If \(candidate-number-limit\) is in SOURCE, show all candidates in SOURCE.
(helm-aif (assq 'candidate-number-limit source)
;; When assoc value is nil use by default 99999999 otherwise use
- ;; the assoc value, when it is a symbol interpret its value (#1831).
+ ;; the assoc value, when it is a symbol interpret its value (bug#1831).
(or (helm-aand (cdr it) (helm-interpret-value it)) 99999999)
(or helm-candidate-number-limit 99999999)))
@@ -4733,7 +4733,7 @@ without recomputing them, it should be a list of lists."
do (helm-render-source src mtc))
;; Move to first line only when there is matches
- ;; to avoid cursor moving upside down (issue #1703).
+ ;; to avoid cursor moving upside down (Bug#1703).
(helm--update-move-first-line)))
;; When there is only one async source, update mode-line and run
@@ -5116,7 +5116,7 @@ This will work only in Emacs-26+, i.e. Emacs versions that have
;; only two chunks. But output could be large and
;; truncated in more than two chunks. Therefore store
- ;; 'newline' to contain the previous chunks (Issue #1187).
+ ;; 'newline' to contain the previous chunks (Bug#1187).
finally do (setcdr incomplete-line-info newline))))
(defun helm-output-filter--post-process ()
@@ -5259,7 +5259,7 @@ If action buffer is selected, back to the Helm buffer."
"Anonymous" actions))
(helm-show-action-buffer actions)
- ;; Be sure the minibuffer is entirely deleted (#907).
+ ;; Be sure the minibuffer is entirely deleted (bug#907).
(helm--delete-minibuffer-contents-from "")
(helm--set-action-prompt)
@@ -5469,11 +5469,11 @@ mode and header lines."
'face 'helm-header-line-left-margin))))
(pos (- (point) beg)))
- ;; Increment pos each time we find a "%" up to current-pos (#1648).
+ ;; Increment pos each time we find a "%" up to current-pos (bug#1648).
(cl-loop for c across (buffer-substring-no-properties beg (point))
when (eql c ?%) do (cl-incf pos))
@@ -6095,7 +6095,7 @@ Optional argument SOURCE is a Helm source object."
(re-search-forward candidate-or-regexp nil t))
;; If search fall on an header line continue loop
- ;; until it match or fail (Issue #1509).
+ ;; until it match or fail (Bug#1509).
(unless (helm-pos-header-line-p) (cl-return (setq mp it))))
(goto-char (or mp start)))))
@@ -6499,7 +6499,7 @@ before running again the init function."
(local local-bname)))
;; We need a buffer not read-only to perhaps insert later
- ;; text coming from read-only buffers (issue #1176).
+ ;; text coming from read-only buffers (Bug#1176).
(set (make-local-variable 'buffer-read-only) nil)
;; Undo is automatically disabled in buffer names starting
@@ -6839,7 +6839,7 @@ unsuitable window to display persistent action buffer."
(with-selected-frame helm-initial-frame (selected-window)))
((and split (not (eq split 'never))) (split-window))
- ;; Fix Issue #2050 with dedicated window.
+ ;; Fix Bug#2050 with dedicated window.
((and (window-dedicated-p
(setq prev-win (previous-window (selected-window) 1)))